@@ -1,7 +1,7 @@
 package TestApp::Action::TestExtraArgsAction;
 
 use Moose;
-use namespace::clean -except => [ 'meta' ];
+use namespace::autoclean;
 
 extends 'Catalyst::Action';
 
